###############################################################################
# International Holiday Data provided by Holidata.net
# http://holidata.net/nb-SJ/2015.json
# http://holidata.net/nb-SJ/2016.json
#
# Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
# http://www.opensource.org/licenses/mit-license.php
#
###############################################################################

holiday.nb-SJ1.name=Nyttårsdag
holiday.nb-SJ1.date=20150101
holiday.nb-SJ2.name=Fastelavn
holiday.nb-SJ2.date=20150215
holiday.nb-SJ3.name=Palmesøndag
holiday.nb-SJ3.date=20150329
holiday.nb-SJ4.name=Skjærtorsdag
holiday.nb-SJ4.date=20150402
holiday.nb-SJ5.name=Langfredag
holiday.nb-SJ5.date=20150403
holiday.nb-SJ6.name=Påskedag
holiday.nb-SJ6.date=20150405
holiday.nb-SJ7.name=Påskedag
holiday.nb-SJ7.date=20150406
holiday.nb-SJ8.name=Offentlig Høytidsdag
holiday.nb-SJ8.date=20150501
holiday.nb-SJ9.name=Frigjøringsdag 1945
holiday.nb-SJ9.date=20150508
holiday.nb-SJ10.name=Grunnlovsdag
holiday.nb-SJ10.date=20150517
holiday.nb-SJ11.name=Kristi Himmelfartsdag
holiday.nb-SJ11.date=20150514
holiday.nb-SJ12.name=Pinsedag
holiday.nb-SJ12.date=20150524
holiday.nb-SJ13.name=Pinsedag
holiday.nb-SJ13.date=20150525
holiday.nb-SJ14.name=Julaften
holiday.nb-SJ14.date=20151224
holiday.nb-SJ15.name=Juledag
holiday.nb-SJ15.date=20151225
holiday.nb-SJ16.name=Juledag
holiday.nb-SJ16.date=20151226
holiday.nb-SJ17.name=Nyttårsaften
holiday.nb-SJ17.date=20151231
holiday.nb-SJ18.name=Nyttårsdag
holiday.nb-SJ18.date=20160101
holiday.nb-SJ19.name=Fastelavn
holiday.nb-SJ19.date=20160207
holiday.nb-SJ20.name=Palmesøndag
holiday.nb-SJ20.date=20160320
holiday.nb-SJ21.name=Skjærtorsdag
holiday.nb-SJ21.date=20160324
holiday.nb-SJ22.name=Langfredag
holiday.nb-SJ22.date=20160325
holiday.nb-SJ23.name=Påskedag
holiday.nb-SJ23.date=20160327
holiday.nb-SJ24.name=Påskedag
holiday.nb-SJ24.date=20160328
holiday.nb-SJ25.name=Offentlig Høytidsdag
holiday.nb-SJ25.date=20160501
holiday.nb-SJ26.name=Frigjøringsdag 1945
holiday.nb-SJ26.date=20160508
holiday.nb-SJ27.name=Grunnlovsdag
holiday.nb-SJ27.date=20160517
holiday.nb-SJ28.name=Kristi Himmelfartsdag
holiday.nb-SJ28.date=20160505
holiday.nb-SJ29.name=Pinsedag
holiday.nb-SJ29.date=20160515
holiday.nb-SJ30.name=Pinsedag
holiday.nb-SJ30.date=20160516
holiday.nb-SJ31.name=Julaften
holiday.nb-SJ31.date=20161224
holiday.nb-SJ32.name=Juledag
holiday.nb-SJ32.date=20161225
holiday.nb-SJ33.name=Juledag
holiday.nb-SJ33.date=20161226
holiday.nb-SJ34.name=Nyttårsaften
holiday.nb-SJ34.date=20161231
