###############################################################################
# International Holiday Data provided by Holidata.net
# http://holidata.net/et-EE/2015.json
# http://holidata.net/et-EE/2016.json
#
# Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
# http://www.opensource.org/licenses/mit-license.php
#
###############################################################################

holiday.et-EE1.name=uusaasta
holiday.et-EE1.date=20150101
holiday.et-EE2.name=iseseisvuspäev
holiday.et-EE2.date=20150224
holiday.et-EE3.name=suur reede
holiday.et-EE3.date=20150403
holiday.et-EE4.name=ülestõusmispühade 1. püha
holiday.et-EE4.date=20150405
holiday.et-EE5.name=kevadpüha
holiday.et-EE5.date=20150501
holiday.et-EE6.name=nelipühade 1. püha
holiday.et-EE6.date=20150524
holiday.et-EE7.name=võidupüha
holiday.et-EE7.date=20150623
holiday.et-EE8.name=jaanipäev
holiday.et-EE8.date=20150624
holiday.et-EE9.name=taasiseseisvumispäev
holiday.et-EE9.date=20150820
holiday.et-EE10.name=jõululaupäev
holiday.et-EE10.date=20151224
holiday.et-EE11.name=esimene jõulupüha
holiday.et-EE11.date=20151225
holiday.et-EE12.name=teine jõulupüha
holiday.et-EE12.date=20151226
holiday.et-EE13.name=uusaasta
holiday.et-EE13.date=20160101
holiday.et-EE14.name=iseseisvuspäev
holiday.et-EE14.date=20160224
holiday.et-EE15.name=suur reede
holiday.et-EE15.date=20160325
holiday.et-EE16.name=ülestõusmispühade 1. püha
holiday.et-EE16.date=20160327
holiday.et-EE17.name=kevadpüha
holiday.et-EE17.date=20160501
holiday.et-EE18.name=nelipühade 1. püha
holiday.et-EE18.date=20160515
holiday.et-EE19.name=võidupüha
holiday.et-EE19.date=20160623
holiday.et-EE20.name=jaanipäev
holiday.et-EE20.date=20160624
holiday.et-EE21.name=taasiseseisvumispäev
holiday.et-EE21.date=20160820
holiday.et-EE22.name=jõululaupäev
holiday.et-EE22.date=20161224
holiday.et-EE23.name=esimene jõulupüha
holiday.et-EE23.date=20161225
holiday.et-EE24.name=teine jõulupüha
holiday.et-EE24.date=20161226
