###############################################################################
# International Holiday Data provided by Holidata.net
# http://holidata.net/en-NZ/2015.json
# http://holidata.net/en-NZ/2016.json
#
# Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
# http://www.opensource.org/licenses/mit-license.php
#
###############################################################################

holiday.en-NZ1.name=New Year's Day
holiday.en-NZ1.date=20150101
holiday.en-NZ2.name=Day after New Years Day
holiday.en-NZ2.date=20150102
holiday.en-NZ3.name=Waitangi Day
holiday.en-NZ3.date=20150206
holiday.en-NZ4.name=Good Friday
holiday.en-NZ4.date=20150403
holiday.en-NZ5.name=Easter Monday
holiday.en-NZ5.date=20150406
holiday.en-NZ6.name=ANZAC Day
holiday.en-NZ6.date=20150425
holiday.en-NZ7.name=Queen's Birthday
holiday.en-NZ7.date=20150601
holiday.en-NZ8.name=Labour Day
holiday.en-NZ8.date=20151026
holiday.en-NZ9.name=Christmas Day
holiday.en-NZ9.date=20151225
holiday.en-NZ10.name=Boxing Day
holiday.en-NZ10.date=20151226
holiday.en-NZ11.name=New Year's Day
holiday.en-NZ11.date=20160101
holiday.en-NZ12.name=Day after New Years Day
holiday.en-NZ12.date=20160104
holiday.en-NZ13.name=Waitangi Day
holiday.en-NZ13.date=20160206
holiday.en-NZ14.name=Good Friday
holiday.en-NZ14.date=20160325
holiday.en-NZ15.name=Easter Monday
holiday.en-NZ15.date=20160328
holiday.en-NZ16.name=ANZAC Day
holiday.en-NZ16.date=20160425
holiday.en-NZ17.name=Queen's Birthday
holiday.en-NZ17.date=20160606
holiday.en-NZ18.name=Labour Day
holiday.en-NZ18.date=20161024
holiday.en-NZ19.name=Christmas Day
holiday.en-NZ19.date=20161225
holiday.en-NZ20.name=Boxing Day
holiday.en-NZ20.date=20161226
