###############################################################################
# International Holiday Data provided by Holidata.net
# http://holidata.net/lv-LV/2015.json
# http://holidata.net/lv-LV/2016.json
#
# Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
# http://www.opensource.org/licenses/mit-license.php
#
###############################################################################

holiday.lv-LV1.name=Jaunais Gads
holiday.lv-LV1.date=20150101
holiday.lv-LV2.name=Lielā Piektdiena
holiday.lv-LV2.date=20150403
holiday.lv-LV3.name=Lieldienas
holiday.lv-LV3.date=20150405
holiday.lv-LV4.name=2. Lieldienas
holiday.lv-LV4.date=20150406
holiday.lv-LV5.name=Darba svētki
holiday.lv-LV5.date=20150501
holiday.lv-LV6.name=Latvijas Republikas Neatkarības atjaunošanas dienu
holiday.lv-LV6.date=20150505
holiday.lv-LV7.name=Jāņi
holiday.lv-LV7.date=20150624
holiday.lv-LV8.name=Latvijas Republikas proklamēšanas diena
holiday.lv-LV8.date=20151118
holiday.lv-LV9.name=Ziemassvētku vakars
holiday.lv-LV9.date=20151224
holiday.lv-LV10.name=Ziemassvētki
holiday.lv-LV10.date=20151225
holiday.lv-LV11.name=2. Ziemassvētki
holiday.lv-LV11.date=20151226
holiday.lv-LV12.name=Vecgada vakars
holiday.lv-LV12.date=20151231
holiday.lv-LV13.name=Jaunais Gads
holiday.lv-LV13.date=20160101
holiday.lv-LV14.name=Lielā Piektdiena
holiday.lv-LV14.date=20160325
holiday.lv-LV15.name=Lieldienas
holiday.lv-LV15.date=20160327
holiday.lv-LV16.name=2. Lieldienas
holiday.lv-LV16.date=20160327
holiday.lv-LV17.name=Darba svētki
holiday.lv-LV17.date=20160501
holiday.lv-LV18.name=Latvijas Republikas Neatkarības atjaunošanas dienu
holiday.lv-LV18.date=20160505
holiday.lv-LV19.name=Jāņi
holiday.lv-LV19.date=20160624
holiday.lv-LV20.name=Latvijas Republikas proklamēšanas diena
holiday.lv-LV20.date=20161118
holiday.lv-LV21.name=Ziemassvētku vakars
holiday.lv-LV21.date=20161224
holiday.lv-LV22.name=Ziemassvētki
holiday.lv-LV22.date=20161225
holiday.lv-LV23.name=2. Ziemassvētki
holiday.lv-LV23.date=20161226
holiday.lv-LV24.name=Vecgada vakars
holiday.lv-LV24.date=20161231
