###############################################################################
# International Holiday Data provided by Holidata.net
# http://holidata.net/en-GL/2015.json
# http://holidata.net/en-GL/2016.json
#
# Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
# http://www.opensource.org/licenses/mit-license.php
#
###############################################################################

holiday.en-GL1.name=New Year's Day
holiday.en-GL1.date=20150101
holiday.en-GL2.name=Epiphany
holiday.en-GL2.date=20150106
holiday.en-GL3.name=Maundy Thursday
holiday.en-GL3.date=20150402
holiday.en-GL4.name=Good Friday
holiday.en-GL4.date=20150303
holiday.en-GL5.name=Easter Monday
holiday.en-GL5.date=20150406
holiday.en-GL6.name=General Prayer Day
holiday.en-GL6.date=20150501
holiday.en-GL7.name=Ascension
holiday.en-GL7.date=20150514
holiday.en-GL8.name=Whit Monday
holiday.en-GL8.date=20150525
holiday.en-GL9.name=Ullortuneq
holiday.en-GL9.date=20150621
holiday.en-GL10.name=Christmas Eve
holiday.en-GL10.date=20151224
holiday.en-GL11.name=Christmas Day
holiday.en-GL11.date=20151225
holiday.en-GL12.name=St Stephen's Day
holiday.en-GL12.date=20151226
holiday.en-GL13.name=New Year's Eve
holiday.en-GL13.date=20151231
holiday.en-GL14.name=New Year's Day
holiday.en-GL14.date=20160101
holiday.en-GL15.name=Epiphany
holiday.en-GL15.date=20160106
holiday.en-GL16.name=Maundy Thursday
holiday.en-GL16.date=20160324
holiday.en-GL17.name=Good Friday
holiday.en-GL17.date=20160325
holiday.en-GL18.name=Easter Monday
holiday.en-GL18.date=20160428
holiday.en-GL19.name=General Prayer Day
holiday.en-GL19.date=20160422
holiday.en-GL20.name=Ascension
holiday.en-GL20.date=20160505
holiday.en-GL21.name=Whit Monday
holiday.en-GL21.date=20160516
holiday.en-GL22.name=Ullortuneq
holiday.en-GL22.date=20160621
holiday.en-GL23.name=Christmas Eve
holiday.en-GL23.date=20161224
holiday.en-GL24.name=Christmas Day
holiday.en-GL24.date=20161225
holiday.en-GL25.name=St Stephen's Day
holiday.en-GL25.date=20161226
holiday.en-GL26.name=New Year's Eve
holiday.en-GL26.date=20161231
