###############################################################################
# International Holiday Data provided by Holidata.net
# http://holidata.net/lt-LT/2015.json
# http://holidata.net/lt-LT/2016.json
#
# Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
# http://www.opensource.org/licenses/mit-license.php
#
###############################################################################

holiday.lt-LT1.name=Naujieji metai
holiday.lt-LT1.date=20150101
holiday.lt-LT2.name=Lietuvos valstybės atkūrimo diena
holiday.lt-LT2.date=20150216
holiday.lt-LT3.name=Lietuvos nepriklausomybės atkūrimo diena
holiday.lt-LT3.date=20150311
holiday.lt-LT4.name=Velykos
holiday.lt-LT4.date=20150405
holiday.lt-LT5.name=Velykos
holiday.lt-LT5.date=20150406
holiday.lt-LT6.name=Tarptautinė darbo diena
holiday.lt-LT6.date=20150501
holiday.lt-LT7.name=Joninės, Rasos
holiday.lt-LT7.date=20150624
holiday.lt-LT8.name=Valstybės diena
holiday.lt-LT8.date=20150706
holiday.lt-LT9.name=Žolinė
holiday.lt-LT9.date=20150815
holiday.lt-LT10.name=Visų šventųjų diena
holiday.lt-LT10.date=20152101
holiday.lt-LT11.name=Šv. Kalėdos
holiday.lt-LT11.date=20151224
holiday.lt-LT12.name=Šv. Kalėdos
holiday.lt-LT12.date=20151225
holiday.lt-LT13.name=Šv. Kalėdos
holiday.lt-LT13.date=20151226
holiday.lt-LT14.name=Naujieji metai
holiday.lt-LT14.date=20160101
holiday.lt-LT15.name=Lietuvos valstybės atkūrimo diena
holiday.lt-LT15.date=20160216
holiday.lt-LT16.name=Lietuvos nepriklausomybės atkūrimo diena
holiday.lt-LT16.date=20160311
holiday.lt-LT17.name=Velykos
holiday.lt-LT17.date=20160327
holiday.lt-LT18.name=Velykos
holiday.lt-LT18.date=20160328
holiday.lt-LT19.name=Tarptautinė darbo diena
holiday.lt-LT19.date=20160501
holiday.lt-LT20.name=Joninės, Rasos
holiday.lt-LT20.date=20160624
holiday.lt-LT21.name=Valstybės diena
holiday.lt-LT21.date=20160706
holiday.lt-LT22.name=Žolinė
holiday.lt-LT22.date=20160815
holiday.lt-LT23.name=Visų šventųjų diena
holiday.lt-LT23.date=20162101
holiday.lt-LT24.name=Šv. Kalėdos
holiday.lt-LT24.date=20161224
holiday.lt-LT25.name=Šv. Kalėdos
holiday.lt-LT25.date=20161225
holiday.lt-LT26.name=Šv. Kalėdos
holiday.lt-LT26.date=20161226
