###############################################################################
# International Holiday Data provided by Holidata.net
# http://holidata.net/es-MX/2015.json
# http://holidata.net/es-MX/2016.json
#
# Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
# http://www.opensource.org/licenses/mit-license.php
#
###############################################################################

holiday.es-MX1.name=Año Nuevo
holiday.es-MX1.date=20150101
holiday.es-MX2.name=Día de la Constitución
holiday.es-MX2.date=20150202
holiday.es-MX3.name=Natalicio de Benito Juárez
holiday.es-MX3.date=20150316
holiday.es-MX4.name=Jueves Santo
holiday.es-MX4.date=20150402
holiday.es-MX5.name=Viernes Santo
holiday.es-MX5.date=20150403
holiday.es-MX6.name=Día del Trabajo
holiday.es-MX6.date=20150501
holiday.es-MX7.name=Día de la Independencia
holiday.es-MX7.date=20150916
holiday.es-MX8.name=Día de la Revolución
holiday.es-MX8.date=20151116
holiday.es-MX9.name=Nuestra Señora de Guadalupe
holiday.es-MX9.date=20151212
holiday.es-MX10.name=Navidad
holiday.es-MX10.date=20151225
holiday.es-MX11.name=Año Nuevo
holiday.es-MX11.date=20160101
holiday.es-MX12.name=Día de la Constitución
holiday.es-MX12.date=20160201
holiday.es-MX13.name=Natalicio de Benito Juárez
holiday.es-MX13.date=20160314
holiday.es-MX14.name=Jueves Santo
holiday.es-MX14.date=20160324
holiday.es-MX15.name=Viernes Santo
holiday.es-MX15.date=20160325
holiday.es-MX16.name=Día del Trabajo
holiday.es-MX16.date=20160501
holiday.es-MX17.name=Día de la Independencia
holiday.es-MX17.date=20160916
holiday.es-MX18.name=Día de la Revolución
holiday.es-MX18.date=20161121
holiday.es-MX19.name=Nuestra Señora de Guadalupe
holiday.es-MX19.date=20161212
holiday.es-MX20.name=Navidad
holiday.es-MX20.date=20161225
