###############################################################################
# International Holiday Data provided by Holidata.net
# http://holidata.net/en-AU/2015.json
# http://holidata.net/en-AU/2016.json
#
# Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
# http://www.opensource.org/licenses/mit-license.php
#
###############################################################################

holiday.en-AU1.name=New Year's Day
holiday.en-AU1.date=20150101
holiday.en-AU2.name=Australia Day
holiday.en-AU2.date=20150126
holiday.en-AU3.name=Royal Hobart Regatta
holiday.en-AU3.date=20150209
holiday.en-AU4.name=Labour Day
holiday.en-AU4.date=20150302
holiday.en-AU5.name=Labour Day
holiday.en-AU5.date=20150309
holiday.en-AU6.name=Canberra Day
holiday.en-AU6.date=20150309
holiday.en-AU7.name=Eight Hours Day
holiday.en-AU7.date=20150309
holiday.en-AU8.name=Good Friday
holiday.en-AU8.date=20150403
holiday.en-AU9.name=Easter Saturday
holiday.en-AU9.date=20150404
holiday.en-AU10.name=Easter Sunday
holiday.en-AU10.date=20150405
holiday.en-AU11.name=Easter Monday
holiday.en-AU11.date=20150406
holiday.en-AU12.name=Anzac Day
holiday.en-AU12.date=20150425
holiday.en-AU13.name=May Day
holiday.en-AU13.date=20150504
holiday.en-AU14.name=Foundation Day
holiday.en-AU14.date=20150601
holiday.en-AU15.name=Queen's Birthday
holiday.en-AU15.date=20150608
holiday.en-AU16.name=Picnic Day
holiday.en-AU16.date=20150803
holiday.en-AU17.name=Bank Holiday
holiday.en-AU17.date=20150803
holiday.en-AU18.name=Queen's Birthday
holiday.en-AU18.date=20150928
holiday.en-AU19.name=Labour Day
holiday.en-AU19.date=20151005
holiday.en-AU20.name=Recreation Day
holiday.en-AU20.date=20151102
holiday.en-AU21.name=Christmas Day
holiday.en-AU21.date=20151225
holiday.en-AU22.name=Boxing Day
holiday.en-AU22.date=20151226
holiday.en-AU23.name=Proclamation Day
holiday.en-AU23.date=20151226
holiday.en-AU24.name=New Year's Day
holiday.en-AU24.date=20160101
holiday.en-AU25.name=Australia Day
holiday.en-AU25.date=20160126
holiday.en-AU26.name=Royal Hobart Regatta
holiday.en-AU26.date=20160208
holiday.en-AU27.name=Labour Day
holiday.en-AU27.date=20160307
holiday.en-AU28.name=Labour Day
holiday.en-AU28.date=20160314
holiday.en-AU29.name=Canberra Day
holiday.en-AU29.date=20160314
holiday.en-AU30.name=Eight Hours Day
holiday.en-AU30.date=20160314
holiday.en-AU31.name=Good Friday
holiday.en-AU31.date=20160325
holiday.en-AU32.name=Easter Saturday
holiday.en-AU32.date=20160326
holiday.en-AU33.name=Easter Monday
holiday.en-AU33.date=20160327
holiday.en-AU34.name=Anzac Day
holiday.en-AU34.date=20160425
holiday.en-AU35.name=May Day
holiday.en-AU35.date=20160502
holiday.en-AU36.name=Foundation Day
holiday.en-AU36.date=20160603
holiday.en-AU37.name=Queen's Birthday
holiday.en-AU37.date=20160613
holiday.en-AU38.name=Picnic Day
holiday.en-AU38.date=20160801
holiday.en-AU39.name=Bank Holiday
holiday.en-AU39.date=20160801
holiday.en-AU40.name=Queen's Birthday
holiday.en-AU40.date=20160926
holiday.en-AU41.name=Labour Day
holiday.en-AU41.date=20161003
holiday.en-AU42.name=Recreation Day
holiday.en-AU42.date=20161107
holiday.en-AU43.name=Christmas Day
holiday.en-AU43.date=20161225
holiday.en-AU44.name=Boxing Day
holiday.en-AU44.date=20161226
holiday.en-AU45.name=Proclamation Day
holiday.en-AU45.date=20161226
