###############################################################################
# International Holiday Data provided by Holidata.net
# http://holidata.net/en-HK/2015.json
# http://holidata.net/en-HK/2016.json
#
# Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
# http://www.opensource.org/licenses/mit-license.php
#
###############################################################################

holiday.en-HK1.name=The first day of January
holiday.en-HK1.date=20150101
holiday.en-HK2.name=Lunar New Year’s Day
holiday.en-HK2.date=20150219
holiday.en-HK3.name=The second day of Lunar New Year
holiday.en-HK3.date=20150220
holiday.en-HK4.name=The third day of Lunar New Year
holiday.en-HK4.date=20150221
holiday.en-HK5.name=Good Friday
holiday.en-HK5.date=20150403
holiday.en-HK6.name=The day following Good Friday
holiday.en-HK6.date=20150404
holiday.en-HK7.name=The day following Ching Ming Festival
holiday.en-HK7.date=20150406
holiday.en-HK8.name=The day following Easter Monday
holiday.en-HK8.date=20150407
holiday.en-HK9.name=Labour Day
holiday.en-HK9.date=20150501
holiday.en-HK10.name=The Birthday of the Buddha
holiday.en-HK10.date=20150525
holiday.en-HK11.name=Tuen Ng Festival
holiday.en-HK11.date=20150620
holiday.en-HK12.name=Hong Kong Special Administrative Region Establishment Day
holiday.en-HK12.date=20150701
holiday.en-HK13.name=The day following the Chinese Mid-Autumn Festival
holiday.en-HK13.date=20150928
holiday.en-HK14.name=National Day
holiday.en-HK14.date=20151001
holiday.en-HK15.name=Chung Yeung Festival
holiday.en-HK15.date=20151021
holiday.en-HK16.name=Christmas Day
holiday.en-HK16.date=20151225
holiday.en-HK17.name=The first weekday after Christmas Day
holiday.en-HK17.date=20151226
holiday.en-HK18.name=The first day of January
holiday.en-HK18.date=20160101
holiday.en-HK19.name=Lunar New Year’s Day
holiday.en-HK19.date=20160208
holiday.en-HK20.name=The second day of Lunar New Year
holiday.en-HK20.date=20160209
holiday.en-HK21.name=The third day of Lunar New Year
holiday.en-HK21.date=20160210
holiday.en-HK22.name=Good Friday
holiday.en-HK22.date=20160325
holiday.en-HK23.name=The day following Good Friday
holiday.en-HK23.date=20160326
holiday.en-HK24.name=Ching Ming Festival
holiday.en-HK24.date=20160404
holiday.en-HK25.name=Labour Day
holiday.en-HK25.date=20160501
holiday.en-HK26.name=The Birthday of the Buddha
holiday.en-HK26.date=20160514
holiday.en-HK27.name=Tuen Ng Festival
holiday.en-HK27.date=20160609
holiday.en-HK28.name=Hong Kong Special Administrative Region Establishment Day
holiday.en-HK28.date=20160701
holiday.en-HK29.name=The day following the Chinese Mid-Autumn Festival
holiday.en-HK29.date=20160916
holiday.en-HK30.name=National Day
holiday.en-HK30.date=20161001
holiday.en-HK31.name=Chung Yeung Festival
holiday.en-HK31.date=20161010
holiday.en-HK32.name=Christmas Day
holiday.en-HK32.date=20161225
holiday.en-HK33.name=The first weekday after Christmas Day
holiday.en-HK33.date=20161226
