###############################################################################
# International Holiday Data provided by Holidata.net
# http://holidata.net/jp-JP/2015.json
# http://holidata.net/jp-JP/2016.json
#
# Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
# http://www.opensource.org/licenses/mit-license.php
#
###############################################################################

holiday.jp-JP1.name=元日
holiday.jp-JP1.date=20150101
holiday.jp-JP2.name=成人の日
holiday.jp-JP2.date=20150112
holiday.jp-JP3.name=建国記念の日
holiday.jp-JP3.date=20150211
holiday.jp-JP4.name=春分の日
holiday.jp-JP4.date=20150321
holiday.jp-JP5.name=昭和の日
holiday.jp-JP5.date=20150429
holiday.jp-JP6.name=憲法記念日
holiday.jp-JP6.date=20150503
holiday.jp-JP7.name=みどりの日
holiday.jp-JP7.date=20150504
holiday.jp-JP8.name=こどもの日
holiday.jp-JP8.date=20150505
holiday.jp-JP9.name=振替休日
holiday.jp-JP9.date=20150506
holiday.jp-JP10.name=海の日
holiday.jp-JP10.date=20150720
holiday.jp-JP11.name=敬老の日
holiday.jp-JP11.date=20150921
holiday.jp-JP12.name=秋分の日
holiday.jp-JP12.date=20150923
holiday.jp-JP13.name=体育の日
holiday.jp-JP13.date=20151012
holiday.jp-JP14.name=文化の日
holiday.jp-JP14.date=20151103
holiday.jp-JP15.name=勤労感謝の日
holiday.jp-JP15.date=20151123
holiday.jp-JP16.name=天皇誕生日
holiday.jp-JP16.date=20151223
holiday.jp-JP17.name=元日
holiday.jp-JP17.date=20160101
holiday.jp-JP18.name=成人の日
holiday.jp-JP18.date=20160111
holiday.jp-JP19.name=建国記念の日
holiday.jp-JP19.date=20160211
holiday.jp-JP20.name=春分の日
holiday.jp-JP20.date=20160321
holiday.jp-JP21.name=昭和の日
holiday.jp-JP21.date=20160429
holiday.jp-JP22.name=憲法記念日
holiday.jp-JP22.date=20160503
holiday.jp-JP23.name=みどりの日
holiday.jp-JP23.date=20160504
holiday.jp-JP24.name=こどもの日
holiday.jp-JP24.date=20160505
holiday.jp-JP25.name=海の日
holiday.jp-JP25.date=20160718
holiday.jp-JP26.name=敬老の日
holiday.jp-JP26.date=20160919
holiday.jp-JP27.name=秋分の日
holiday.jp-JP27.date=20160922
holiday.jp-JP28.name=体育の日
holiday.jp-JP28.date=20161010
holiday.jp-JP29.name=文化の日
holiday.jp-JP29.date=20161103
holiday.jp-JP30.name=勤労感謝の日
holiday.jp-JP30.date=20161123
holiday.jp-JP31.name=天皇誕生日
holiday.jp-JP31.date=20161223
