###############################################################################
# International Holiday Data provided by Holidata.net
# http://holidata.net/be-BY/2015.json
# http://holidata.net/be-BY/2016.json
#
# Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
# http://www.opensource.org/licenses/mit-license.php
#
###############################################################################

holiday.be-BY1.name=Новы Год
holiday.be-BY1.date=20150101
holiday.be-BY2.name=Раство Хрыстова(праваслаўнае)
holiday.be-BY2.date=20150107
holiday.be-BY3.name=Міжнародны жаночы дзень
holiday.be-BY3.date=20150803
holiday.be-BY4.name=Пасха(праваслаўная)
holiday.be-BY4.date=20150420
holiday.be-BY5.name=Радуніца
holiday.be-BY5.date=20150421
holiday.be-BY6.name=Свята працы
holiday.be-BY6.date=20150501
holiday.be-BY7.name=Дзень Перамогі
holiday.be-BY7.date=20150509
holiday.be-BY8.name=Дзень незалежнаці
holiday.be-BY8.date=20150703
holiday.be-BY9.name=Дзень Кастрычніцкай рэвалюцыі
holiday.be-BY9.date=20151107
holiday.be-BY10.name=Раство Хрыстова(у заходніх хрысціян)
holiday.be-BY10.date=20151225
holiday.be-BY11.name=Новы Год
holiday.be-BY11.date=20160101
holiday.be-BY12.name=Раство Хрыстова(праваслаўнае)
holiday.be-BY12.date=20160107
holiday.be-BY13.name=Міжнародны жаночы дзень
holiday.be-BY13.date=20160803
holiday.be-BY14.name=Пасха(праваслаўная)
holiday.be-BY14.date=20160327
holiday.be-BY15.name=Радуніца
holiday.be-BY15.date=20160510
holiday.be-BY16.name=Свята працы
holiday.be-BY16.date=20160501
holiday.be-BY17.name=Дзень Перамогі
holiday.be-BY17.date=20160509
holiday.be-BY18.name=Дзень незалежнаці
holiday.be-BY18.date=20160703
holiday.be-BY19.name=Дзень Кастрычніцкай рэвалюцыі
holiday.be-BY19.date=20161107
holiday.be-BY20.name=Раство Хрыстова(у заходніх хрысціян)
holiday.be-BY20.date=20161225
