###############################################################################
# International Holiday Data provided by Holidata.net
# http://holidata.net/ga-IE/2015.json
# http://holidata.net/ga-IE/2016.json
#
# Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
# http://www.opensource.org/licenses/mit-license.php
#
###############################################################################

holiday.ga-IE1.name=Lá Caille or Lá Bliana Nua
holiday.ga-IE1.date=20150101
holiday.ga-IE2.name=Lá Fhéile Pádraig
holiday.ga-IE2.date=20150317
holiday.ga-IE3.name=Luan Cásca
holiday.ga-IE3.date=20150406
holiday.ga-IE4.name=Lá an Lucht Oibre
holiday.ga-IE4.date=20150504
holiday.ga-IE5.name=Lá Saoire i mí Mheitheamh
holiday.ga-IE5.date=20150601
holiday.ga-IE6.name=Lá Saoire i mí Lúnasa
holiday.ga-IE6.date=20150803
holiday.ga-IE7.name=Lá Saoire i mí Dheireadh Fómhair
holiday.ga-IE7.date=20151026
holiday.ga-IE8.name=Lá Nollag
holiday.ga-IE8.date=20151225
holiday.ga-IE9.name=Lá Fhéile Stiofáin or Lá an Dreoilín
holiday.ga-IE9.date=20151226
holiday.ga-IE10.name=Lá Caille or Lá Bliana Nua
holiday.ga-IE10.date=20160101
holiday.ga-IE11.name=Lá Fhéile Pádraig
holiday.ga-IE11.date=20160317
holiday.ga-IE12.name=Luan Cásca
holiday.ga-IE12.date=20160328
holiday.ga-IE13.name=Lá an Lucht Oibre
holiday.ga-IE13.date=20160502
holiday.ga-IE14.name=Lá Saoire i mí Mheitheamh
holiday.ga-IE14.date=20160606
holiday.ga-IE15.name=Lá Saoire i mí Lúnasa
holiday.ga-IE15.date=20160801
holiday.ga-IE16.name=Lá Saoire i mí Dheireadh Fómhair
holiday.ga-IE16.date=20161031
holiday.ga-IE17.name=Lá Nollag
holiday.ga-IE17.date=20161225
holiday.ga-IE18.name=Lá Fhéile Stiofáin or Lá an Dreoilín
holiday.ga-IE18.date=20161226
