###############################################################################
# International Holiday Data provided by Holidata.net
# http://holidata.net/de-AT/2015.json
# http://holidata.net/de-AT/2016.json
#
# Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
# http://www.opensource.org/licenses/mit-license.php
#
###############################################################################

holiday.de-AT1.name=Neujahr
holiday.de-AT1.date=20150101
holiday.de-AT2.name=Heilige drei KÃ¶nige
holiday.de-AT2.date=20150106
holiday.de-AT3.name=Josef (K, St, T, V)
holiday.de-AT3.date=20150319
holiday.de-AT4.name=Karfreitag
holiday.de-AT4.date=20150403
holiday.de-AT5.name=Ostersonntag
holiday.de-AT5.date=20150405
holiday.de-AT6.name=Ostermontag
holiday.de-AT6.date=20150406
holiday.de-AT7.name=Staatsfeiertag
holiday.de-AT7.date=20150501
holiday.de-AT8.name=Florian (O)
holiday.de-AT8.date=20150504
holiday.de-AT9.name=Christi Himmelfahrt
holiday.de-AT9.date=20150514
holiday.de-AT10.name=Pfingstsonntag
holiday.de-AT10.date=20150524
holiday.de-AT11.name=Pfingstmontag
holiday.de-AT11.date=20150525
holiday.de-AT12.name=Fronleichnam
holiday.de-AT12.date=20150604
holiday.de-AT13.name=Mariä Himmelfahrt
holiday.de-AT13.date=20150815
holiday.de-AT14.name=Rupert (S)
holiday.de-AT14.date=20150924
holiday.de-AT15.name=Tag der Volksabstimmung (K)
holiday.de-AT15.date=20151010
holiday.de-AT16.name=Allerheiligen
holiday.de-AT16.date=20151101
holiday.de-AT17.name=Martin (B)
holiday.de-AT17.date=20151111
holiday.de-AT18.name=Leopold (W, N)
holiday.de-AT18.date=20151115
holiday.de-AT19.name=Mariä Empfängnis
holiday.de-AT19.date=20151208
holiday.de-AT20.name=Heiliger Abend
holiday.de-AT20.date=20151224
holiday.de-AT21.name=Christtag
holiday.de-AT21.date=20151225
holiday.de-AT22.name=Stefanitag
holiday.de-AT22.date=20151226
holiday.de-AT23.name=Silvester
holiday.de-AT23.date=20151231
holiday.de-AT24.name=Neujahr
holiday.de-AT24.date=20160101
holiday.de-AT25.name=Heilige drei KÃ¶nige
holiday.de-AT25.date=20160106
holiday.de-AT26.name=Josef (K, St, T, V)
holiday.de-AT26.date=20160319
holiday.de-AT27.name=Karfreitag
holiday.de-AT27.date=20160325
holiday.de-AT28.name=Ostersonntag
holiday.de-AT28.date=20160327
holiday.de-AT29.name=Ostermontag
holiday.de-AT29.date=20160328
holiday.de-AT30.name=Staatsfeiertag
holiday.de-AT30.date=20160501
holiday.de-AT31.name=Florian (O)
holiday.de-AT31.date=20160504
holiday.de-AT32.name=Christi Himmelfahrt
holiday.de-AT32.date=20160505
holiday.de-AT33.name=Pfingstsonntag
holiday.de-AT33.date=20160515
holiday.de-AT34.name=Pfingstmontag
holiday.de-AT34.date=20160516
holiday.de-AT35.name=Fronleichnam
holiday.de-AT35.date=20160526
holiday.de-AT36.name=Mariä Himmelfahrt
holiday.de-AT36.date=20160815
holiday.de-AT37.name=Rupert (S)
holiday.de-AT37.date=20160924
holiday.de-AT38.name=Tag der Volksabstimmung (K)
holiday.de-AT38.date=20161010
holiday.de-AT39.name=Allerheiligen
holiday.de-AT39.date=20161101
holiday.de-AT40.name=Martin (B)
holiday.de-AT40.date=20161111
holiday.de-AT41.name=Leopold (W, N)
holiday.de-AT41.date=20161115
holiday.de-AT42.name=Mariä Empfängnis
holiday.de-AT42.date=20161208
holiday.de-AT43.name=Heiliger Abend
holiday.de-AT43.date=20161224
holiday.de-AT44.name=Christtag
holiday.de-AT44.date=20161225
holiday.de-AT45.name=Stefanitag
holiday.de-AT45.date=20161226
holiday.de-AT46.name=Silvester
holiday.de-AT46.date=20161231
