###############################################################################
# International Holiday Data provided by Holidata.net
# http://holidata.net/es-EC/2015.json
# http://holidata.net/es-EC/2016.json
#
# Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
# http://www.opensource.org/licenses/mit-license.php
#
###############################################################################

holiday.es-EC1.name=Año Nuevo
holiday.es-EC1.date=20150101
holiday.es-EC2.name=Año Nuevo
holiday.es-EC2.date=20150102
holiday.es-EC3.name=Carnaval
holiday.es-EC3.date=20150216
holiday.es-EC4.name=Carnaval
holiday.es-EC4.date=20150217
holiday.es-EC5.name=Viernes Santo
holiday.es-EC5.date=20150403
holiday.es-EC6.name=Día del Trabajo
holiday.es-EC6.date=20150501
holiday.es-EC7.name=Batalla del Pichincha
holiday.es-EC7.date=20150524
holiday.es-EC8.name=Primer Grito de Independencia
holiday.es-EC8.date=20150810
holiday.es-EC9.name=Independencia de Guayaquil
holiday.es-EC9.date=20151009
holiday.es-EC10.name=Día de Difuntos
holiday.es-EC10.date=20151102
holiday.es-EC11.name=Independencia de Cuenca
holiday.es-EC11.date=20151103
holiday.es-EC12.name=Navidad
holiday.es-EC12.date=20151225
holiday.es-EC13.name=Año Nuevo
holiday.es-EC13.date=20160101
holiday.es-EC14.name=Carnaval
holiday.es-EC14.date=20160208
holiday.es-EC15.name=Carnaval
holiday.es-EC15.date=20160209
holiday.es-EC16.name=Viernes Santo
holiday.es-EC16.date=20160325
holiday.es-EC17.name=Día del Trabajo
holiday.es-EC17.date=20160501
holiday.es-EC18.name=Batalla del Pichincha
holiday.es-EC18.date=20160524
holiday.es-EC19.name=Primer Grito de Independencia
holiday.es-EC19.date=20160810
holiday.es-EC20.name=Independencia de Guayaquil
holiday.es-EC20.date=20161009
holiday.es-EC21.name=Día de Difuntos
holiday.es-EC21.date=20161102
holiday.es-EC22.name=Independencia de Cuenca
holiday.es-EC22.date=20161103
holiday.es-EC23.name=Navidad
holiday.es-EC23.date=20161225
