###############################################################################
# International Holiday Data provided by Holidata.net
# http://holidata.net/pt-BR/2015.json
# http://holidata.net/pt-BR/2016.json
#
# Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
# http://www.opensource.org/licenses/mit-license.php
#
###############################################################################

holiday.pt-BR1.name=Confraternização Universal
holiday.pt-BR1.date=20150101
holiday.pt-BR2.name=Carnaval
holiday.pt-BR2.date=20150216
holiday.pt-BR3.name=Carnaval
holiday.pt-BR3.date=20150217
holiday.pt-BR4.name=Sexta-feira Santa
holiday.pt-BR4.date=20150403
holiday.pt-BR5.name=Páscoa
holiday.pt-BR5.date=20150405
holiday.pt-BR6.name=Tiradentes
holiday.pt-BR6.date=20150421
holiday.pt-BR7.name=Dia do Trabalho
holiday.pt-BR7.date=20150501
holiday.pt-BR8.name=Corpus Christi
holiday.pt-BR8.date=20150604
holiday.pt-BR9.name=Independência do Brasil
holiday.pt-BR9.date=20150907
holiday.pt-BR10.name=Nossa Senhora Aparecida
holiday.pt-BR10.date=20151012
holiday.pt-BR11.name=Finados
holiday.pt-BR11.date=20151102
holiday.pt-BR12.name=Proclamação da República
holiday.pt-BR12.date=20151115
holiday.pt-BR13.name=Natal
holiday.pt-BR13.date=20151225
holiday.pt-BR14.name=Confraternização Universal
holiday.pt-BR14.date=20160101
holiday.pt-BR15.name=Carnaval
holiday.pt-BR15.date=20160208
holiday.pt-BR16.name=Carnaval
holiday.pt-BR16.date=20160209
holiday.pt-BR17.name=Sexta-feira Santa
holiday.pt-BR17.date=20160325
holiday.pt-BR18.name=Páscoa
holiday.pt-BR18.date=20160327
holiday.pt-BR19.name=Tiradentes
holiday.pt-BR19.date=20160421
holiday.pt-BR20.name=Dia do Trabalho
holiday.pt-BR20.date=20160501
holiday.pt-BR21.name=Corpus Christi
holiday.pt-BR21.date=20160526
holiday.pt-BR22.name=Independência do Brasil
holiday.pt-BR22.date=20160907
holiday.pt-BR23.name=Nossa Senhora Aparecida
holiday.pt-BR23.date=20161012
holiday.pt-BR24.name=Finados
holiday.pt-BR24.date=20161102
holiday.pt-BR25.name=Proclamação da República
holiday.pt-BR25.date=20161115
holiday.pt-BR26.name=Natal
holiday.pt-BR26.date=20161225
