###############################################################################
# International Holiday Data provided by Holidata.net
# http://holidata.net/en-ZA/2015.json
# http://holidata.net/en-ZA/2016.json
#
# Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
# http://www.opensource.org/licenses/mit-license.php
#
###############################################################################

holiday.en-ZA1.name=New Year's Day
holiday.en-ZA1.date=20150101
holiday.en-ZA2.name=Human Rights Day
holiday.en-ZA2.date=20150321
holiday.en-ZA3.name=Good Friday
holiday.en-ZA3.date=20150403
holiday.en-ZA4.name=Family Day
holiday.en-ZA4.date=20150406
holiday.en-ZA5.name=Freedom Day
holiday.en-ZA5.date=20150427
holiday.en-ZA6.name=Workers' Day
holiday.en-ZA6.date=20150501
holiday.en-ZA7.name=Youth Day
holiday.en-ZA7.date=20150616
holiday.en-ZA8.name=National Women's Day
holiday.en-ZA8.date=20150809
holiday.en-ZA9.name=Heritage Day
holiday.en-ZA9.date=20150924
holiday.en-ZA10.name=Day of Reconciliation
holiday.en-ZA10.date=20151217
holiday.en-ZA11.name=Christmas Day
holiday.en-ZA11.date=20151225
holiday.en-ZA12.name=Day of Goodwill
holiday.en-ZA12.date=20151226
holiday.en-ZA13.name=New Year's Day
holiday.en-ZA13.date=20160101
holiday.en-ZA14.name=Human Rights Day
holiday.en-ZA14.date=20160321
holiday.en-ZA15.name=Good Friday
holiday.en-ZA15.date=20160325
holiday.en-ZA16.name=Family Day
holiday.en-ZA16.date=20160328
holiday.en-ZA17.name=Freedom Day
holiday.en-ZA17.date=20160427
holiday.en-ZA18.name=Workers' Day
holiday.en-ZA18.date=20160501
holiday.en-ZA19.name=Youth Day
holiday.en-ZA19.date=20160616
holiday.en-ZA20.name=National Women's Day
holiday.en-ZA20.date=20160809
holiday.en-ZA21.name=Heritage Day
holiday.en-ZA21.date=20160924
holiday.en-ZA22.name=Day of Reconciliation
holiday.en-ZA22.date=20161217
holiday.en-ZA23.name=Christmas Day
holiday.en-ZA23.date=20161225
holiday.en-ZA24.name=Day of Goodwill
holiday.en-ZA24.date=20161226
